##
#     Project: Awaitable
# Description: A decorator to asynchronously execute synchronous functions
#      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
#   Copyright: 2022 Fabio Castelli
#     License: GPL-3+
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
##

APP_NAME = 'Awaitable'
APP_VERSION = '0.2.1'
APP_DESCRIPTION = 'A decorator to asynchronously execute synchronous functions'
APP_ID = 'awaitable.muflone.com'
APP_URL = 'http://www.muflone.com/awaitable/'
APP_AUTHOR = 'Fabio Castelli'
APP_AUTHOR_EMAIL = 'muflone@muflone.com'
APP_COPYRIGHT = 'Copyright 2022 %s' % APP_AUTHOR
